==> tutti-ichtyometer-3.2-sources.jar: fr/ifremer/tutti/ichtyometer/RemoteDeviceNotFoundException.java <==
package fr.ifremer.tutti.ichtyometer;

/*
 * #%L
 * Tutti :: Ichtyometer API
 * $Id: RemoteDeviceNotFoundException.java 1573 2014-02-04 16:41:40Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.2/tutti-ichtyometer/src/main/java/fr/ifremer/tutti/ichtyometer/RemoteDeviceNotFoundException.java $
 * %%
 * Copyright (C) 2012 - 2014 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.io.IOException;

/**
 * If remote device is not found.
 * <p/>
 * Created on 1/27/14.
 *
 * @author Tony Chemit <chemit@codelutin.com>
 * @since 3.1
 */
public class RemoteDeviceNotFoundException extends IOException {

    private static final long serialVersionUID = 1L;

    public RemoteDeviceNotFoundException(String message) {
        super(message);
    }

    public RemoteDeviceNotFoundException(String message, Throwable cause) {
        super(message, cause);
    }

    public RemoteDeviceNotFoundException(Throwable cause) {
        super(cause);
    }
}

==> tutti-ichtyometer-3.2.1-sources.jar: fr/ifremer/tutti/ichtyometer/RemoteDeviceNotFoundException.java <==
package fr.ifremer.tutti.ichtyometer;

/*
 * #%L
 * Tutti :: Ichtyometer API
 * $Id: RemoteDeviceNotFoundException.java 1573 2014-02-04 16:41:40Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.2.1/tutti-ichtyometer/src/main/java/fr/ifremer/tutti/ichtyometer/RemoteDeviceNotFoundException.java $
 * %%
 * Copyright (C) 2012 - 2014 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.io.IOException;

/**
 * If remote device is not found.
 * <p/>
 * Created on 1/27/14.
 *
 * @author Tony Chemit <chemit@codelutin.com>
 * @since 3.1
 */
public class RemoteDeviceNotFoundException extends IOException {

    private static final long serialVersionUID = 1L;

    public RemoteDeviceNotFoundException(String message) {
        super(message);
    }

    public RemoteDeviceNotFoundException(String message, Throwable cause) {
        super(message, cause);
    }

    public RemoteDeviceNotFoundException(Throwable cause) {
        super(cause);
    }
}
